===========================
Installing Django Evolution
===========================

To install Django Evolution, simply run::

    $ pip install django_evolution

You'll probably want to add that as a package dependency to your project.

Then add ``django_evolution`` to your project's
:django:setting:`INSTALLED_APPS`.
